@@ -1,7 +1,7 @@
 import json
 import os
 
-from ..default_files import GITIGNORE, SETTINGS_JSON
+from ..default_files import GITIGNORE, SETTINGS_JSON, DOCKERIGNORE
 
 
 ################################################################
@@ -52,3 +52,13 @@ def _generate_gitignore(root):
     content = GITIGNORE
     fp = os.path.join(root, FILE)
     _makedir_and_write(fp, content)
+
+
+################################################################
+# .dockerignore
+################################################################
+def _generate_dockerignore(root):
+    FILE = ".dockerignore"
+    content = DOCKERIGNORE
+    fp = os.path.join(root, FILE)
+    _makedir_and_write(fp, content)
